﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading;
using System.Threading.Tasks;
using InternshipSystem.Api.Security;
using InternshipSystem.Core.Entity.Internship;
using InternshipSystem.Repository;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc;
using Microsoft.EntityFrameworkCore;

namespace InternshipSystem.Api.Controllers
{
    [ApiController]
    [Route("internshipType")]
    public class InternshipTypesController : ControllerBase
    {
        
        public InternshipTypesController(InternshipDbContext context)
        {
            Context = context;
        }
        private InternshipDbContext Context { get; }
        
        /// <summary>
        /// Get static page
        /// </summary>
        /// <returns>List of internship types for edition</returns>
        [HttpGet]
        [ProducesResponseType(StatusCodes.Status200OK)]
        [ProducesResponseType(StatusCodes.Status401Unauthorized)]
        [ProducesResponseType(StatusCodes.Status404NotFound)]
        [Authorize(Policy = Policies.RegisteredOnly)]
        public async Task<ActionResult<IList<InternshipType>>> GetInternshipTypesForEdition([FromServices] User user, CancellationToken cancellationToken)
        {
            var edition = 
                await Context.Editions
                    .Include(e => e.AvailableInternshipTypes)
                    .Where(e => e.Id.Equals(user.EditionId))
                    .FirstOrDefaultAsync(cancellationToken: cancellationToken);

            if (edition == null)
            {
                return NotFound();
            }

            return Ok(edition.AvailableInternshipTypes);
        }
    }
}