﻿using System.Collections.Generic;
using System.Linq;
using System.Threading;
using System.Threading.Tasks;
using InternshipSystem.Core;
using InternshipSystem.Repository;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc;
using Microsoft.EntityFrameworkCore;

namespace InternshipSystem.Api.Controllers
{
    [ApiController]
    [Route("staticPage")]
    public class StaticPagesController : ControllerBase
    {
        public StaticPagesController(InternshipDbContext context)
        {
            Context = context;
        }
        private InternshipDbContext Context { get; }
        
        /// <summary>
        /// Get all static pages
        /// </summary>
        /// <returns>List of static pages with titles and content</returns>
        [HttpGet]
        [ProducesResponseType(StatusCodes.Status200OK)]
        public async Task<ActionResult<IList<StaticPage>>> GetStaticPages(CancellationToken cancellationToken) =>
            await Context.StaticPages
                .ToListAsync(cancellationToken);

        /// <summary>
        /// Get static page
        /// </summary>
        /// <param name="accessName">Name of page</param>
        /// <returns>Static page title and content</returns>
        [HttpGet("{accessName}")]
        [ProducesResponseType(StatusCodes.Status200OK)]
        [ProducesResponseType(StatusCodes.Status404NotFound)]
        public async Task<ActionResult<StaticPage>> GetStaticPage(string accessName, CancellationToken cancellationToken)
        {
            var page = 
                await Context.StaticPages
                    .Where(p => p.AccessName.Trim().ToLower().Equals(accessName.Trim().ToLower()))
                    .FirstOrDefaultAsync(cancellationToken);

            if (page == null)
            {
                return NotFound();
            }

            return Ok(page);
        }
    }
}