﻿using System;
using System.Linq;
using System.Security.Claims;
using System.Threading.Tasks;
using InternshipSystem.Api.Security;
using Microsoft.AspNetCore.Mvc.ModelBinding;

namespace InternshipSystem.Api.ModelBinders
{
    public class UserBinder : IModelBinder
    {
        public Task BindModelAsync(ModelBindingContext bindingContext)
        {
            if (bindingContext == null)
            {
                throw new ArgumentNullException(nameof(bindingContext));
            }

            var principal = bindingContext.HttpContext.User;

            if (principal == null)
            {
                return Task.CompletedTask;
            }

            Guid? editionGuid = null;
            if (principal.FindFirst(InternshipClaims.Edition) != null 
                && Guid.TryParse(principal.FindFirst(InternshipClaims.Edition).Value, out var edition))
            {
                editionGuid = edition;
            }
            
            var user = new User
            {
                Name = principal.FindFirst(ClaimTypes.Name).Value,
                PersonNumber = long.Parse(principal.FindFirst(InternshipClaims.PersonNumber).Value),
                EditionId = editionGuid
            }; 
            
            bindingContext.Result = ModelBindingResult.Success(user);
            return Task.CompletedTask;
        }
    }
}