﻿using FluentValidation;

namespace InternshipSystem.Api.Queries
{
    public class BranchOfficeForm
    {
        public long? Id { get; set; }
        public string Street { get; set; }
        public string Building { get; set; }
        public string City { get; set; }
        public string PostalCode { get; set; }
        public string Country { get; set; }
        
        public class Validator : AbstractValidator<BranchOfficeForm>
        {
            public Validator()
            {
                RuleFor(b => b.Id).NotNull()
                    .When(c => 
                        !string.IsNullOrEmpty(c.Country) || !string.IsNullOrEmpty(c.City) || 
                        !string.IsNullOrEmpty(c.PostalCode) || !string.IsNullOrEmpty(c.Street) || 
                        !string.IsNullOrEmpty(c.Building));
                RuleFor(b => b.Country).NotNull()
                    .When(b => !b.Id.HasValue);
                RuleFor(b => b.City).NotNull()
                    .When(b => !b.Id.HasValue);
                RuleFor(b => b.PostalCode).NotNull()
                    .When(b => !b.Id.HasValue);
                RuleFor(b => b.Street).NotNull()
                    .When(b => !b.Id.HasValue);
                RuleFor(b => b.Building).NotNull()
                    .When(b => !b.Id.HasValue);
            }
        }
    }
}